@@ -78,6 +78,199 @@ namespace Cairo
 class Surface
 {
 public:
+  /**
+   * Type is used to describe the type of a given surface. The
+   * surface types are also known as "backends" or "surface backends" within
+   * cairo.
+   *
+   * The surface type can be queried with Surface::get_type()
+   *
+   * The various Cairo::Surface functions can be used with surfaces of
+   * any type, but some backends also provide type-specific functions
+   * that must only be called with a surface of the appropriate
+   * type.
+   *
+   * New entries may be added in future versions.
+   *
+   * @since 1.2
+   **/
+  enum class Type
+  {
+      /**
+       * The surface is of type image
+       */
+      IMAGE = CAIRO_SURFACE_TYPE_IMAGE,
+
+      /**
+       * The surface is of type pdf
+       */
+      PDF = CAIRO_SURFACE_TYPE_PDF,
+
+      /**
+       * The surface is of type ps
+       */
+      PS = CAIRO_SURFACE_TYPE_PS,
+
+      /**
+       * The surface is of type xlim
+       */
+      XLIB = CAIRO_SURFACE_TYPE_XLIB,
+
+      /**
+       * The surface is of type xcb
+       */
+      XCB = CAIRO_SURFACE_TYPE_XCB,
+
+      /**
+       * The surface is of type glitz
+       */
+      GLITZ = CAIRO_SURFACE_TYPE_GLITZ,
+
+      /**
+       * The surface is of type quartz
+       */
+      QUARTZ = CAIRO_SURFACE_TYPE_QUARTZ,
+
+      /**
+       * The surface is of type win32
+       */
+      WIN32 = CAIRO_SURFACE_TYPE_WIN32,
+
+      /**
+       * The surface is of type beos
+       */
+      BEOS = CAIRO_SURFACE_TYPE_BEOS,
+
+      /**
+       * The surface is of type directfb
+       */
+      DIRECTFB = CAIRO_SURFACE_TYPE_DIRECTFB,
+
+      /**
+       * The surface is of type svg
+       */
+      SVG = CAIRO_SURFACE_TYPE_SVG,
+
+      /**
+       * The surface is of type os2
+       */
+      OS2 = CAIRO_SURFACE_TYPE_OS2,
+
+      /**
+       * The surface is a win32 printing surface
+       */
+      WIN32_PRINTING = CAIRO_SURFACE_TYPE_WIN32_PRINTING,
+
+      /**
+       * The surface is of type quartz_image
+       */
+      QUARTZ_IMAGE = CAIRO_SURFACE_TYPE_QUARTZ_IMAGE,
+
+      /**
+       * The surface is of type script
+       * @since 1.10
+       */
+      SCRIPT = CAIRO_SURFACE_TYPE_SCRIPT,
+
+      /**
+       * The surface is of type Qt
+       * @since 1.10
+       */
+      QT = CAIRO_SURFACE_TYPE_QT,
+
+      /**
+       * The surface is of type recording
+       * @since 1.10
+       */
+      RECORDING = CAIRO_SURFACE_TYPE_RECORDING,
+
+      /**
+       * The surface is a OpenVg surface
+       * @since 1.10
+       */
+      VG = CAIRO_SURFACE_TYPE_VG,
+
+      /**
+       * The surface is of type OpenGl
+       * @since 1.10
+       */
+      GL = CAIRO_SURFACE_TYPE_GL,
+
+      /**
+       * The surface is of type Direct Render Manager
+       * @since 1.10
+       */
+      DRM = CAIRO_SURFACE_TYPE_DRM,
+
+      /**
+       * The surface is of type script 'tee' (a multiplexing surface)
+       * @since 1.10
+       */
+      TEE = CAIRO_SURFACE_TYPE_TEE,
+
+      /**
+       * The surface is of type XML (for debugging)
+       * @since 1.10
+       */
+      XML = CAIRO_SURFACE_TYPE_XML,
+
+      /**
+       * The surface is of type Skia
+       * @since 1.10
+       */
+      SKIA = CAIRO_SURFACE_TYPE_SKIA,
+
+      /**
+       * The surface is of type The surface is a subsurface created with
+       * Surface::create()
+       * @since 1.10
+       */
+      SUBSURFACE = CAIRO_SURFACE_TYPE_SUBSURFACE
+
+  };
+
+  /**
+   * Format is used to identify the memory format of
+   * image data.
+   *
+   * New entries may be added in future versions.
+   **/
+  enum class Format
+  {
+      /**
+       * Each pixel is a 32-bit quantity, with alpha in the upper 8 bits, then
+       * red, then green, then blue. The 32-bit quantities are stored
+       * native-endian. Pre-multiplied alpha is used. (That is, 50% transparent
+       * red is 0x80800000,
+       */
+      ARGB32 = CAIRO_FORMAT_ARGB32,
+
+      /**
+       * Each pixel is a 32-bit quantity, with the upper 8 bits unused. Red,
+       * Green, and Blue are stored in the remaining 24 bits in that order.
+       */
+      RGB24 = CAIRO_FORMAT_RGB24,
+
+      /**
+       * Each pixel is a 8-bit quantity holding an alpha value
+       */
+      A8 = CAIRO_FORMAT_A8,
+
+      /**
+       * Each pikel is a 1-bit quentity holding an alpha value. Pixels are packed
+       * together into 32-bit quantities. The ordering of the bits matches the
+       * endianess of the platform. On a big-endian machine, the first pixel is in
+       * the uppermost bit, on a little endian machine the first pixel is in the
+       * least-significant bit.
+       */
+      A1 = CAIRO_FORMAT_A1,
+
+      /**
+       * Each fixel is a 16-bit quantity with red in the upper 5 bits, then green
+       * in the middle 6 bits, and blue in the lower 5 bits
+       */
+      RGB16_565 = CAIRO_FORMAT_RGB16_565
+  };
   /** For example:
    * <code>
    * ErrorStatus my_write_func(unsigned char* data, unsigned int length);
@@ -92,7 +285,7 @@ public:
    * @param length the amount of data to write
    * @return the status code of the write operation
    */
-  typedef sigc::slot<ErrorStatus, const unsigned char* /*data*/, unsigned int /*length*/> SlotWriteFunc;
+  typedef sigc::slot<ErrorStatus(const unsigned char* /*data*/, unsigned int /*length*/)> SlotWriteFunc;
 
   /**
    * This is the type of function which is called when a backend needs to read
@@ -105,7 +298,7 @@ public:
    * @param length the amount of data to read
    * @return the status code of the read operation
    */
-  typedef sigc::slot<ErrorStatus, unsigned char* /*data*/, unsigned int /*length*/> SlotReadFunc;
+  typedef sigc::slot<ErrorStatus(unsigned char* /*data*/, unsigned int /*length*/)> SlotReadFunc;
 
   /** Create a C++ wrapper for the C instance. This C++ instance should then be
    * given to a RefPtr.
@@ -137,7 +330,7 @@ public:
   /** For instance,
    * void on_destroy();
    */
-  typedef sigc::slot<void> SlotDestroy;
+  typedef sigc::slot<void()> SlotDestroy;
 
   /** Attach an image in the format mime_type to surface. To remove the data from
    * a surface, call unset_mime_data() with same mime type.
@@ -281,7 +474,7 @@ public:
    */
   void get_fallback_resolution(double& x_pixels_per_inch, double& y_pixels_per_inch) const;
 
-  SurfaceType get_type() const;
+  Type get_type() const;
 
   /**
    * This function returns the content type of surface which indicates whether
@@ -346,9 +539,6 @@ public:
    */
   void write_to_png_stream(const SlotWriteFunc& write_func);
 
-  /** @deprecated Use write_to_png_stream instead */
-  void write_to_png(cairo_write_func_t write_func, void *closure);
-
 #endif // CAIRO_HAS_PNG_FUNCTIONS
 
   /** This function returns the device for a surface
@@ -422,7 +612,7 @@ protected:
 
 /** Image surfaces provide the ability to render to memory buffers either
  * allocated by cairo or by the calling code. The supported image formats are
- * those defined in Cairo::Format
+ * those defined in Format
  *
  * An ImageSurface is the most generic type of Surface and the only one that is
  * available by default.  You can either create an ImageSurface whose data is
@@ -505,14 +695,14 @@ public:
    * surface = Cairo::ImageSurface::create (data, format, width, height);
    * @endcode
    *
-   * @param format A Cairo::Format value
+   * @param format A Format value
    * @param width The desired width of an image surface to be created.
    * @return the appropriate stride to use given the desired format and width, or
    * -1 if either the format is invalid or the width too large.
    *
    * @since 1.6
    **/
-  static int format_stride_for_width(Cairo::Format format, int width);
+  static int format_stride_for_width(Format format, int width);
 
   /**
    * Creates an image surface of the specified format and dimensions. Initially
@@ -576,8 +766,6 @@ public:
    * contents of the PNG image file.
    */
   static RefPtr<ImageSurface> create_from_png_stream(const SlotReadFunc& read_func);
-  /** @deprecated Use create_from_png_stream instead */
-  static RefPtr<ImageSurface> create_from_png(cairo_read_func_t read_func, void *closure);
 
 #endif // CAIRO_HAS_PNG_FUNCTIONS
 
@@ -645,7 +833,7 @@ public:
    * @return true if the recording surface is bounded, false if the recording
    * surface is unbounded (in which case `extents` will not be set).
    */
-  bool get_extents(Rectangle &extents) const;
+  bool get_extents(Rectangle& extents) const;
 
   /**
    * Creates a recording surface which can be used to record all drawing
@@ -738,8 +926,6 @@ public:
    * @since 1.8
    */
   static RefPtr<PdfSurface> create_for_stream(const SlotWriteFunc& write_func, double width_in_points, double height_in_points);
-  /** @deprecated use PdfSurface::create_for_stream() instead */
-  static RefPtr<PdfSurface> create(cairo_write_func_t write_func, void *closure, double width_in_points, double height_in_points);
 
 /**
  * Changes the size of a PDF surface for the current (and subsequent) pages.
@@ -841,8 +1027,6 @@ public:
    * @since 1.8
    */
   static RefPtr<PsSurface> create_for_stream(const SlotWriteFunc& write_func, double width_in_points, double height_in_points);
-  /** @deprecated use PsSurface::create_for_stream() instead */
-  static RefPtr<PsSurface> create(cairo_write_func_t write_func, void *closure, double width_in_points, double height_in_points);
 
   /**
    * Changes the size of a PostScript surface for the current (and
@@ -998,9 +1182,6 @@ public:
    */
   static RefPtr<SvgSurface> create_for_stream(const SlotWriteFunc& write_func, double width_in_points, double height_in_points);
 
-  /** @deprecated Use SvgSurface::create_for_stream() instead */
-  static RefPtr<SvgSurface> create(cairo_write_func_t write_func, void *closure, double width_in_points, double height_in_points);
-
   /**
    * Restricts the generated SVG file to the given version. See get_versions()
    * for a list of available version values that can be used here.
